@@ -2,11 +2,13 @@
 """
 NEST v2 implementation of the PyNN API.
 
-:copyright: Copyright 2006-2011 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2013 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 
-$Id: __init__.py 957 2011-05-03 13:44:15Z apdavison $
+$Id: __init__.py 1257 2013-01-31 14:19:50Z apdavison $
 """
+
+import numpy
 import nest
 from pyNN.nest import simulator
 from pyNN import common, recording, errors, space, __doc__
@@ -16,7 +18,6 @@ recording.simulator = simulator
 if recording.MPI and (nest.Rank() != recording.mpi_comm.rank):
     raise Exception("MPI not working properly. Please make sure you import pyNN.nest before pyNN.random.")
 
-import numpy
 import os
 import shutil
 import logging
@@ -82,6 +83,11 @@ def setup(timestep=0.1, min_delay=0.1, max_delay=10.0, **extra_params):
     global tempdir
     
     common.setup(timestep, min_delay, max_delay, **extra_params)
+    # clear the sli stack, if this is not done --> memory leak cause the stack increases
+    nest.sr('clear')
+    
+    # reset the simulation kernel
+    nest.ResetKernel()
     
     if 'verbosity' in extra_params:
         nest_verbosity = extra_params['verbosity'].upper()
@@ -96,14 +102,7 @@ def setup(timestep=0.1, min_delay=0.1, max_delay=10.0, **extra_params):
     nest.SetKernelStatus({'off_grid_spiking': simulator.state.spike_precision=='off_grid'})
     if "recording_precision" in extra_params:
         simulator.state.default_recording_precision = extra_params["recording_precision"]
-    
-    
-    # clear the sli stack, if this is not done --> memory leak cause the stack increases
-    nest.sr('clear')
-    
-    # reset the simulation kernel
-    nest.ResetKernel()
-    
+        
     # all NEST to erase previously written files (defaut with all the other simulators)
     nest.SetKernelStatus({'overwrite_files' : True})
     
@@ -127,14 +126,19 @@ def setup(timestep=0.1, min_delay=0.1, max_delay=10.0, **extra_params):
     # set resolution
     nest.SetKernelStatus({'resolution': timestep})
 
+    if 'allow_offgrid_spikes' in nest.GetDefaults('spike_generator'):
+        nest.SetDefaults('spike_generator', {'allow_offgrid_spikes': True})
+
     # Set min_delay and max_delay for all synapse models
+    NEST_SYNAPSE_TYPES = nest.Models(mtype='synapses')  # need to rebuild after ResetKernel
     for synapse_model in NEST_SYNAPSE_TYPES:
         nest.SetDefaults(synapse_model, {'delay' : min_delay,
                                          'min_delay': min_delay,
                                          'max_delay': max_delay})
     simulator.connection_managers = []
+    simulator.populations = []
     simulator.reset()
-    
+
     return rank()
  
 def end(compatible_output=True):
@@ -214,6 +218,7 @@ class Population(common.Population):
         if hasattr(celltype, "uses_parrot") and celltype.uses_parrot:
             for gid, source in zip(self.all_cells, self.all_cells_source):
                 gid.source = source
+        simulator.populations.append(self)
         
 
     def set(self, param, val=None):
