@@ -1,6 +1,6 @@
 """
 
-:copyright: Copyright 2006-2011 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2013 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 """
 
@@ -157,6 +157,7 @@ class RecordingDevice(object):
         # what if the method is called with different values of
         # `compatible_output`? Need to cache these separately.
         if self._local_files_merged:
+            logger.debug("Loading merged data from cache")
             self._merged_file.seek(0)
             data = numpy.load(self._merged_file)
         else:
@@ -169,7 +170,8 @@ class RecordingDevice(object):
             logger.debug("Concatenating data from the following files: %s" % ", ".join(nest_files))
             non_empty_nest_files = [filename for filename in nest_files if os.stat(filename).st_size > 0]
             if len(non_empty_nest_files) > 0:
-                data_list = [numpy.loadtxt(nest_file) for nest_file in non_empty_nest_files]
+                data_list = [numpy.atleast_2d(numpy.loadtxt(nest_file))
+                             for nest_file in non_empty_nest_files]
                 data = numpy.concatenate(data_list)
             if len(non_empty_nest_files) == 0 or data.size == 0:
                 if self.type is "spike_detector":
@@ -182,7 +184,7 @@ class RecordingDevice(object):
                 data = self.add_initial_values(data)
             self._merged_file = tempfile.TemporaryFile()
             numpy.save(self._merged_file, data)
-            self._local_files_merged = True
+            self._local_files_merged = True  # this is set back to False by run()
         return data
     
     def read_data(self, gather, compatible_output, always_local=False):
@@ -297,18 +299,18 @@ class Recorder(recording.Recorder):
             events = nest.GetStatus(self._device.device, 'events')[0]
             for id in filtered_ids:
                 mask = events['senders'] == int(id)
-                N[id] = len(events['times'][mask])
+                N[int(id)] = len(events['times'][mask])
         else:
             spikes = self._get(gather=False, compatible_output=False,
                                filter=filter)
             for id in self.filter_recorded(filter):
-                N[id] = 0
+                N[int(id)] = 0
             ids   = numpy.sort(spikes[:,0].astype(int))
             idx   = numpy.unique(ids)
             left  = numpy.searchsorted(ids, idx, 'left')
             right = numpy.searchsorted(ids, idx, 'right')
             for id, l, r in zip(idx, left, right):
-                N[id] = r-l
+                N[int(id)] = r-l
         return N
     
 simulator.Recorder = Recorder # very inelegant. Need to rethink the module structure
