@@ -23,10 +23,10 @@ All other functions and classes are private, and should not be used by other
 modules.
 
 
-:copyright: Copyright 2006-2011 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2013 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 
-$Id: simulator.py 957 2011-05-03 13:44:15Z apdavison $
+$Id: simulator.py 1258 2013-01-31 15:01:25Z apdavison $
 """
 
 import nest
@@ -39,6 +39,7 @@ CHECK_CONNECTIONS = False
 recorder_list = []
 recording_devices = []
 connection_managers = []
+populations = []
 
 global net
 net    = None
@@ -92,6 +93,7 @@ def run(simtime):
     """Advance the simulation for a certain time."""
     for device in recording_devices:
         device.connect_to_cells()
+        device._local_files_merged = False
     if not state.running:
         simtime += state.dt # we simulate past the real time by one time step, otherwise NEST doesn't give us all the recorded data
         state.running = True
@@ -100,8 +102,12 @@ def run(simtime):
 def reset():
     nest.ResetNetwork()
     nest.SetKernelStatus({'time': 0.0})
+    for p in populations:
+        for name, value in p.initial_values.items():
+            p.initialize(name, value)
     state.running = False
 
+
 # --- For implementation of access to individual neurons' parameters ----------- 
 
 class ID(int, common.IDMixin):
