@@ -1,7 +1,7 @@
 """
 Definition of NativeSynapseType class for NEST
 
-:copyright: Copyright 2006-2011 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2013 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 """
 
@@ -13,7 +13,8 @@ DEFAULT_TAU_MINUS = 20.0
 def get_defaults(model_name):
     defaults = nest.GetDefaults(model_name)
     ignore = ['delay', 'max_delay', 'min_delay', 'num_connections',
-              'num_connectors', 'receptor_type', 'synapsemodel', 'weight']
+              'num_connectors', 'synapsemodel', 'weight',
+              'property_object', 'type']
     default_params = {}
     for name,value in defaults.items():
         if name not in ignore:
@@ -21,11 +22,8 @@ def get_defaults(model_name):
     default_params['tau_minus'] = DEFAULT_TAU_MINUS
     return default_params
 
-
-
-
 class NativeSynapseDynamics(BaseSynapseDynamics):
-    
+
     def __init__(self, model_name, parameters={}):
         cls = type(model_name, (NativeSynapseMechanism,),
                    {'nest_model': model_name})
@@ -34,7 +32,7 @@ class NativeSynapseDynamics(BaseSynapseDynamics):
     def _get_nest_synapse_model(self, suffix):
         defaults = self.mechanism.parameters.copy()
         defaults.pop("tau_minus")
-        label = "%s_%s" % (self.mechanism.nest_model, suffix) 
+        label = "%s_%s" % (self.mechanism.nest_model, suffix)
         nest.CopyModel(self.mechanism.nest_model,
                        label,
                        defaults)
@@ -51,7 +49,7 @@ class NativeSynapseDynamics(BaseSynapseDynamics):
 
 
 class NativeSynapseMechanism(BaseModelType):
-    
+
     def __new__(cls, parameters):
         cls.default_parameters = get_defaults(cls.nest_model)
         return super(NativeSynapseMechanism, cls).__new__(cls)
